==> codeready-workspaces-2.4.1-GA-crwctl3-sources.tar.gz: crwctl/lib/commands/server/update.js <==
"use strict";
/*********************************************************************
 * Copyright (c) 2019 Red Hat, Inc.
 *
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 **********************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const flags_1 = require("@oclif/parser/lib/flags");
const cli_ux_1 = require("cli-ux");
const fs = require("fs-extra");
const Listr = require("listr");
const notifier = require("node-notifier");
const path = require("path");
const kube_1 = require("../../api/kube");
const common_flags_1 = require("../../common-flags");
const constants_1 = require("../../constants");
const che_1 = require("../../tasks/che");
const common_tasks_1 = require("../../tasks/installers/common-tasks");
const installer_1 = require("../../tasks/installers/installer");
const api_1 = require("../../tasks/platforms/api");
const common_platform_tasks_1 = require("../../tasks/platforms/common-platform-tasks");
const platform_1 = require("../../tasks/platforms/platform");
const util_1 = require("../../util");
class Update extends command_1.Command {
    static getTemplatesDir() {
        // return local templates folder if present
        const TEMPLATES = 'templates';
        const templatesDir = path.resolve(TEMPLATES);
        const exists = fs.pathExistsSync(templatesDir);
        if (exists) {
            return TEMPLATES;
        }
        // else use the location from modules
        return path.join(__dirname, '../../../templates');
    }
    checkIfInstallerSupportUpdating(flags) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            if (!flags.installer) {
                yield this.setDefaultInstaller(flags);
                cli_ux_1.cli.info(`› Installer type is set to: '${flags.installer}'`);
            }
            if (flags.installer === 'operator' || flags.installer === 'olm') {
                // operator already supports updating
                return;
            }
            if (flags.installer === 'olm' && flags.platform === 'minishift') {
                this.error(`🛑 The specified installer ${flags.installer} does not support Minishift`);
            }
        });
    }
    run() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const { flags } = this.parse(Update);
            const ctx = {};
            const listrOptions = { renderer: flags['listr-renderer'], collapse: false };
            ctx.listrOptions = listrOptions;
            // Holds messages which should be printed at the end of crwctl log
            ctx.highlightedMessages = [];
            const cheTasks = new che_1.CheTasks(flags);
            const platformTasks = new platform_1.PlatformTasks();
            const installerTasks = new installer_1.InstallerTasks();
            const apiTasks = new api_1.ApiTasks();
            // Platform Checks
            const platformCheckTasks = new Listr(platformTasks.preflightCheckTasks(flags, this), listrOptions);
            platformCheckTasks.add(common_platform_tasks_1.CommonPlatformTasks.oAuthProvidersExists(flags));
            yield this.checkIfInstallerSupportUpdating(flags);
            // Checks if CodeReady Workspaces is already deployed
            let preInstallTasks = new Listr(undefined, listrOptions);
            preInstallTasks.add(apiTasks.testApiTasks(flags, this));
            preInstallTasks.add({
                title: '👀  Looking for an already existing CodeReady Workspaces instance',
                task: () => new Listr(cheTasks.checkIfCheIsInstalledTasks(flags, this))
            });
            const preUpdateTasks = new Listr(installerTasks.preUpdateTasks(flags, this), listrOptions);
            const updateTasks = new Listr(undefined, listrOptions);
            updateTasks.add({
                title: '↺  Updating...',
                task: () => new Listr(installerTasks.updateTasks(flags, this))
            });
            const postUpdateTasks = new Listr(undefined, listrOptions);
            postUpdateTasks.add(common_tasks_1.getPrintHighlightedMessagesTask());
            try {
                yield preInstallTasks.run(ctx);
                if (!ctx.isCheDeployed) {
                    this.error('CodeReady Workspaces deployment is not found. Use `crwctl server:start` to initiate new deployment.');
                }
                else {
                    if (util_1.isKubernetesPlatformFamily(flags.platform)) {
                        yield this.setDomainFlag(flags);
                    }
                    yield platformCheckTasks.run(ctx);
                    yield preUpdateTasks.run(ctx);
                    if (!flags['skip-version-check'] && flags.installer !== 'olm') {
                        yield cli_ux_1.cli.anykey(`      Found deployed CodeReady Workspaces with operator [${ctx.deployedCheOperatorImage}]:${ctx.deployedCheOperatorTag}.
      You are going to update it to [${ctx.newCheOperatorImage}]:${ctx.newCheOperatorTag}.
      Note that CodeReady Workspaces operator will update component images (server, plugin registry) only if their values
      are not overridden in eclipse-che Custom Resource. So, you may need to remove them manually.
      Press q to quit or any key to continue`);
                    }
                    yield updateTasks.run(ctx);
                    yield postUpdateTasks.run(ctx);
                }
                this.log('Command server:update has completed successfully.');
            }
            catch (err) {
                this.error(err);
            }
            notifier.notify({
                title: 'crwctl',
                message: 'Command server:start has completed successfully.'
            });
            this.exit(0);
        });
    }
    setDomainFlag(flags) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const kubeHelper = new kube_1.KubeHelper(flags);
            const cheCluster = yield kubeHelper.getCheCluster(flags.chenamespace);
            if (cheCluster && cheCluster.spec.k8s && cheCluster.spec.k8s.ingressDomain) {
                flags.domain = cheCluster.spec.k8s.ingressDomain;
            }
        });
    }
    setDefaultInstaller(flags) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const kubeHelper = new kube_1.KubeHelper(flags);
            try {
                yield kubeHelper.getOperatorSubscription(constants_1.SUBSCRIPTION_NAME, flags.chenamespace);
                flags.installer = 'olm';
            }
            catch (_a) {
                flags.installer = 'operator';
            }
        });
    }
}
exports.default = Update;
Update.description = 'update CodeReady Workspaces server';
Update.flags = {
    installer: flags_1.string({
        char: 'a',
        description: 'Installer type. If not set, default is autodetected depending on previous installation.',
        options: ['operator', 'olm'],
    }),
    platform: flags_1.string({
        char: 'p',
        description: 'Type of OpenShift platform. Valid values are \"openshift\", \"crc (for CodeReady Containers)\".',
        options: ['openshift', 'crc'],
        default: 'openshift'
    }),
    chenamespace: common_flags_1.cheNamespace,
    templates: flags_1.string({
        char: 't',
        description: 'Path to the templates folder',
        default: Update.getTemplatesDir(),
        env: 'CHE_TEMPLATES_FOLDER'
    }),
    'che-operator-image': flags_1.string({
        description: 'Container image of the operator. This parameter is used only when the installer is the operator',
        default: constants_1.DEFAULT_CHE_OPERATOR_IMAGE
    }),
    'skip-version-check': flags_1.boolean({
        description: 'Skip user confirmation on version check',
        default: false
    }),
    'deployment-name': common_flags_1.cheDeployment,
    'listr-renderer': common_flags_1.listrRenderer,
    'skip-kubernetes-health-check': common_flags_1.skipKubeHealthzCheck,
    help: command_1.flags.help({ char: 'h' }),
};
//# sourceMappingURL=update.js.map

==> codeready-workspaces-2.5.0-GA-crwctl3-sources.tar.gz: crwctl/lib/commands/server/update.js <==
"use strict";
/*********************************************************************
 * Copyright (c) 2019 Red Hat, Inc.
 *
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 **********************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const flags_1 = require("@oclif/parser/lib/flags");
const cli_ux_1 = require("cli-ux");
const fs = require("fs-extra");
const Listr = require("listr");
const notifier = require("node-notifier");
const path = require("path");
const kube_1 = require("../../api/kube");
const common_flags_1 = require("../../common-flags");
const constants_1 = require("../../constants");
const che_1 = require("../../tasks/che");
const common_tasks_1 = require("../../tasks/installers/common-tasks");
const installer_1 = require("../../tasks/installers/installer");
const api_1 = require("../../tasks/platforms/api");
const common_platform_tasks_1 = require("../../tasks/platforms/common-platform-tasks");
const platform_1 = require("../../tasks/platforms/platform");
const util_1 = require("../../util");
class Update extends command_1.Command {
    static getTemplatesDir() {
        // return local templates folder if present
        const TEMPLATES = 'templates';
        const templatesDir = path.resolve(TEMPLATES);
        const exists = fs.pathExistsSync(templatesDir);
        if (exists) {
            return TEMPLATES;
        }
        // else use the location from modules
        return path.join(__dirname, '../../../templates');
    }
    checkIfInstallerSupportUpdating(flags) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            if (!flags.installer) {
                yield this.setDefaultInstaller(flags);
                cli_ux_1.cli.info(`› Installer type is set to: '${flags.installer}'`);
            }
            if (flags.installer === 'operator' || flags.installer === 'olm') {
                // operator already supports updating
                return;
            }
            if (flags.installer === 'olm' && flags.platform === 'minishift') {
                this.error(`🛑 The specified installer ${flags.installer} does not support Minishift`);
            }
        });
    }
    run() {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const { flags } = this.parse(Update);
            const ctx = util_1.initializeContext();
            const listrOptions = { renderer: flags['listr-renderer'], collapse: false };
            ctx.listrOptions = listrOptions;
            const cheTasks = new che_1.CheTasks(flags);
            const kubeHelper = new kube_1.KubeHelper(flags);
            const platformTasks = new platform_1.PlatformTasks();
            const installerTasks = new installer_1.InstallerTasks();
            const apiTasks = new api_1.ApiTasks();
            // Platform Checks
            const platformCheckTasks = new Listr(platformTasks.preflightCheckTasks(flags, this), listrOptions);
            platformCheckTasks.add(common_platform_tasks_1.CommonPlatformTasks.oAuthProvidersExists(flags));
            yield this.checkIfInstallerSupportUpdating(flags);
            // Checks if CodeReady Workspaces is already deployed
            let preInstallTasks = new Listr(undefined, listrOptions);
            preInstallTasks.add(apiTasks.testApiTasks(flags, this));
            preInstallTasks.add({
                title: '👀  Looking for an already existing CodeReady Workspaces instance',
                task: () => new Listr(cheTasks.checkIfCheIsInstalledTasks(flags, this))
            });
            const preUpdateTasks = new Listr(installerTasks.preUpdateTasks(flags, this), listrOptions);
            const updateTasks = new Listr(undefined, listrOptions);
            updateTasks.add({
                title: '↺  Updating...',
                task: () => new Listr(installerTasks.updateTasks(flags, this))
            });
            const postUpdateTasks = new Listr(undefined, listrOptions);
            postUpdateTasks.add(common_tasks_1.getPrintHighlightedMessagesTask());
            try {
                yield preInstallTasks.run(ctx);
                if (!ctx.isCheDeployed) {
                    this.error('CodeReady Workspaces deployment is not found. Use `crwctl server:deploy` to initiate a new deployment.');
                }
                else {
                    if (util_1.isKubernetesPlatformFamily(flags.platform)) {
                        yield this.setDomainFlag(flags);
                    }
                    yield platformCheckTasks.run(ctx);
                    yield preUpdateTasks.run(ctx);
                    if (!flags['skip-version-check'] && flags.installer === 'operator') {
                        cli_ux_1.cli.info(`Existed CodeReady Workspaces operator: ${ctx.deployedCheOperatorImage}:${ctx.deployedCheOperatorTag}.`);
                        cli_ux_1.cli.info(`New CodeReady Workspaces operator    : ${ctx.newCheOperatorImage}:${ctx.newCheOperatorTag}.`);
                        if (flags['che-operator-image'] !== constants_1.DEFAULT_CHE_OPERATOR_IMAGE) {
                            cli_ux_1.cli.warn(`This command updates CodeReady Workspaces to ${util_1.getImageTag(constants_1.DEFAULT_CHE_OPERATOR_IMAGE)} version, but custom operator image is specified.`);
                            cli_ux_1.cli.warn('Make sure that the new version of the CodeReady Workspaces is corresponding to the version of the tool you use.');
                            cli_ux_1.cli.warn('Consider using \'crwctl update [stable|next]\' to update to the latest version of crwctl.');
                        }
                        const cheCluster = yield kubeHelper.getCheCluster(flags.chenamespace);
                        if (cheCluster.spec.server.cheImage
                            || cheCluster.spec.server.devfileRegistryImage
                            || cheCluster.spec.database.postgresImage
                            || cheCluster.spec.server.pluginRegistryImage
                            || cheCluster.spec.auth.identityProviderImage) {
                            cli_ux_1.cli.warn(`CodeReady Workspaces operator won't update some components since their images are defined
            in the '${cheCluster.metadata.name}' Custom Resource of the namespace '${flags.chenamespace}'
            Please consider removing them from the Custom Resource when update is completed:`);
                            cheCluster.spec.server.cheImage && cli_ux_1.cli.warn(`CodeReady Workspaces server [${cheCluster.spec.server.cheImage}:${cheCluster.spec.server.cheImageTag}]`);
                            cheCluster.spec.database.postgresImage && cli_ux_1.cli.warn(`Database [${cheCluster.spec.database.postgresImage}]`);
                            cheCluster.spec.server.devfileRegistryImage && cli_ux_1.cli.warn(`Devfile registry [${cheCluster.spec.server.devfileRegistryImage}]`);
                            cheCluster.spec.server.pluginRegistryImage && cli_ux_1.cli.warn(`Plugin registry [${cheCluster.spec.server.pluginRegistryImage}]`);
                            cheCluster.spec.auth.identityProviderImage && cli_ux_1.cli.warn(`Identity provider [${cheCluster.spec.auth.identityProviderImage}]`);
                        }
                        const confirmed = yield cli_ux_1.cli.confirm('If you want to continue - press Y');
                        if (!confirmed) {
                            this.exit(0);
                        }
                    }
                    yield updateTasks.run(ctx);
                    yield postUpdateTasks.run(ctx);
                }
                this.log(util_1.getCommandSuccessMessage(this, ctx));
            }
            catch (err) {
                this.error(err);
            }
            notifier.notify({
                title: 'crwctl',
                message: util_1.getCommandSuccessMessage(this, ctx)
            });
            this.exit(0);
        });
    }
    setDomainFlag(flags) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const kubeHelper = new kube_1.KubeHelper(flags);
            const cheCluster = yield kubeHelper.getCheCluster(flags.chenamespace);
            if (cheCluster && cheCluster.spec.k8s && cheCluster.spec.k8s.ingressDomain) {
                flags.domain = cheCluster.spec.k8s.ingressDomain;
            }
        });
    }
    setDefaultInstaller(flags) {
        return tslib_1.__awaiter(this, void 0, void 0, function* () {
            const kubeHelper = new kube_1.KubeHelper(flags);
            try {
                yield kubeHelper.getOperatorSubscription(constants_1.SUBSCRIPTION_NAME, flags.chenamespace);
                flags.installer = 'olm';
            }
            catch (_a) {
                flags.installer = 'operator';
            }
        });
    }
}
exports.default = Update;
Update.description = 'Update CodeReady Workspaces server.';
Update.flags = {
    installer: flags_1.string({
        char: 'a',
        description: 'Installer type. If not set, default is autodetected depending on previous installation.',
        options: ['operator', 'olm'],
    }),
    platform: flags_1.string({
        char: 'p',
        description: 'Type of OpenShift platform. Valid values are \"openshift\", \"crc (for CodeReady Containers)\".',
        options: ['openshift', 'crc'],
        default: 'openshift'
    }),
    chenamespace: common_flags_1.cheNamespace,
    templates: flags_1.string({
        char: 't',
        description: 'Path to the templates folder',
        default: Update.getTemplatesDir(),
        env: 'CHE_TEMPLATES_FOLDER'
    }),
    'che-operator-image': flags_1.string({
        description: 'Container image of the operator. This parameter is used only when the installer is the operator',
        default: constants_1.DEFAULT_CHE_OPERATOR_IMAGE
    }),
    'skip-version-check': flags_1.boolean({
        description: 'Skip user confirmation on version check',
        default: false
    }),
    'deployment-name': common_flags_1.cheDeployment,
    'listr-renderer': common_flags_1.listrRenderer,
    'skip-kubernetes-health-check': common_flags_1.skipKubeHealthzCheck,
    help: command_1.flags.help({ char: 'h' }),
};
//# sourceMappingURL=update.js.map
